<template>
  <div class="common-page-shadow">
    <div class="common-search-container" ref="contentPanel">
      <el-form
        ref="form"
        label-position="right "
        :inline="true"
        type="flex"
        justify="left"
      >
        <el-form-item label="专家编号">
          <el-input
            size="small"
            v-model="querys[0].value"
            clearable
            placeholder="请输入专家编号"
          ></el-input>
        </el-form-item>
        <el-form-item label="专家名称">
          <el-input
            size="small"
            v-model="querys[1].value"
            clearable
            placeholder="请输入专家名称"
          ></el-input>
        </el-form-item>
      </el-form>
      <div class="container-btn">
        <el-button
          size="small"
          icon="el-icon-search"
          type="danger"
          class="btn btn-plus"
          @click="handleSearch"
        >
          搜索
        </el-button>
        <el-button
          size="small"
          icon="el-icon-refresh-right"
          class="btn btn-plus"
          @click="clearSearchForm"
        >
          重置
        </el-button>
      </div>
    </div>
    <el-row
      class="common-table-container flex searchPanel"
      :style="SearchPanel"
    >
      <el-col :span="24" class="common-table-wrapper">
        <div class="common-btn-group">
          <el-button
            size="small"
            icon="el-icon-plus"
            type="primary"
            class="btn btn-plus"
            @click="handleAdd"
          >
            新增
          </el-button>
          <el-button
            :disabled="handleDeleteActive"
            size="small"
            type="danger"
            icon="el-icon-delete"
            @click="handleDelete"
          >
            删除
          </el-button>
        </div>
        <!-- LJ：表格高度自适应需配合样式  btn-pagenation 有按钮有分页  btngroup只有按钮  pagenation只有分页 -->
        <div class="common-table-content btn-pagenation" ref="tableContent">
          <el-table
            :border="true"
            stripe
            fit
            size="mini"
            v-loading="tableLoading"
            :max-height="tableHeight"
            ref="multipleSelection"
            :data="tableData"
            @selection-change="handleSelectionChange"
            @row-dblclick="handleDetail"
          >
            <el-table-column type="selection" min-width="5%" align="center">
            </el-table-column>
            <el-table-column
              prop="orgName"
              show-overflow-tooltip
              min-width="10%"
              align="center"
              label="单位名称"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="userNumber"
              min-width="10%"
              label="专家编号"
              align="center"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="fullname"
              show-overflow-tooltip
              min-width="10%"
              align="center"
              label="专家名称"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="nation"
              show-overflow-tooltip
              min-width="15%"
              align="center"
              label="民族"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="address"
              show-overflow-tooltip
              min-width="10%"
              align="center"
              label="工作地址"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="idCard"
              show-overflow-tooltip
              min-width="10%"
              align="center"
              label="身份证号"
              resizable
            >
              <template slot-scope="scope">
                <div>
                  {{ maskedIdCard(scope.row.idCard) }}
                </div>
              </template>
            </el-table-column>
            <el-table-column
              prop="birthday"
              show-overflow-tooltip
              min-width="10%"
              align="center"
              label="出生日期"
              resizable
            >
            </el-table-column>
            <el-table-column
              prop="mobile"
              show-overflow-tooltip
              min-width="10%"
              align="center"
              label="手机"
              resizable
            >
              <template slot-scope="scope">
                <div>
                  {{ maskedIdCard(scope.row.mobile) }}
                </div>
              </template>
            </el-table-column>
            <el-table-column
              prop="email"
              show-overflow-tooltip
              min-width="10%"
              align="center"
              label="Email"
              resizable
            >
            </el-table-column>
            <!-- <el-table-column
              prop="account"
              show-overflow-tooltip
              min-width="10%"
              align="center"
              label="门户帐号"
              resizable
            >
            </el-table-column> -->
            <el-table-column min-width="10%" align="center" label="操作">
              <template v-slot="{row}">
                <template>
                  <el-button
                    icon="el-icon-edit"
                    type="primary"
                    plain
                    size="small"
                    @click="handleEdit(row)"
                    >编辑</el-button
                  >
                </template>
              </template>
            </el-table-column>
          </el-table>
        </div>
        <div class="common-pagenation">
          <el-pagination
            ref="paginationPanel"
            background
            @size-change="handleSizeChange"
            @current-change="handleCurrentChange"
            :current-page="queryParam.pageBean.page"
            :page-sizes="[20, 30, 40, 50]"
            :page-size="queryParam.pageBean.pageSize"
            layout="total, sizes, prev, pager, next, jumper"
            :total="queryParam.pageBean.total"
          >
          </el-pagination>
        </div>
      </el-col>
    </el-row>
  </div>
</template>

<script>
import pagination from '@/components/pagination'
import {TableMixin} from '@/mixins/tableMixin'
import utils from '@/utils.js'
import basicData from '@/api/basicData'
export default {
  name: 'DemandEntry',
  components: {
    pagination,
  },
  mixins: [TableMixin],
  data() {
    return {
      currentPage: 1,
      tableHeight: 400,
      tableLoading: false,
      handleDeleteActive: true,
      handleDeleteId: [],
      tableData: [],
      queryParam: {
        pageBean: {
          page: 1,
          pageSize: 20,
          total: 0,
        },
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'userNumber',
          relation: 'AND',
          value: '',
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'fullname',
          relation: 'AND',
          value: '',
        },
        {
          group: 'orgQuery',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'orgId',
          relation: 'OR',
          value: '',
        },
        {
          group: 'orgQuery',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'createOrgId',
          relation: 'OR',
          value: '',
        },
      ],
    }
  },
  mounted() {
    //页面缩放从新计算表格的高度
    window.addEventListener('resize', this.calcTableHeight)
  },
  created() {
    this.currentUser = JSON.parse(sessionStorage.getItem('currentUserDetail'))
    this.querys[2].value = this.currentUser.org[0].orgId
    this.querys[3].value = this.currentUser.org[0].orgId
    this.loadData()
  },
  beforeDestroy() {
    //切换页面卸载监听器
    window.removeEventListener('resize', this.calcTableHeight)
  },
  methods: {
    // 动态计算表格的高度，自适应当前容器
    calcTableHeight() {
      console.log(this.$refs.tableContent.offsetHeight)
      this.tableHeight = this.$refs.tableContent.offsetHeight
    },
    getDictName(code, value) {
      return utils.getDictName(code, value)
    },
    //获取数据
    loadData() {
      this.tableLoading = true
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }
      this.queryParam.sorter = [
        {
          direction: 'DESC',
          property: 'create_time_',
        },
      ]
      basicData.bizExpertDatabaseQuery(this.queryParam).then((res) => {
        this.queryParam.pageBean.total = res.total
        this.tableLoading = false
        this.tableData = res.rows
      })
    },
    //添加
    handleAdd() {
      this.$router.push('expertPoolAddDialog')
    },
    // 编辑
    handleEdit(rows) {
      this.$refs.form.clearValidate()
      this.$router.push({
        name: 'expertPoolAddDialog',
        query: {editRows: rows, pageBean: this.queryParam},
      })
    },
    maskedIdCard(val) {
      let reg = /^(.{3})(?:\d+)(.{3})$/ // 匹配身份证号前3位和后3位的正则表达式
      if (val) {
        return val.replace(reg, '$1******$2')
      }
    },
    // 删除
    handleDelete() {
      this.$confirm('确定删除选中数据？', '提示', {
        confirmButtonText: '确 定',
        cancelButtonText: '取 消',
        type: 'warning',
      })
        .then(() => {
          basicData.bizExpertDatabaseRemove(this.handleDeleteId).then((res) => {
            if (res.state) {
              this.$message.success(res.message)
              this.loadData()
            }
          })
        })
        .catch(() => {})
    },
    // 详情
    handleDetail(rows) {
      this.$router.push({
        name: 'expertDetail',
        query: {detailRows: rows, pageBean: this.queryParam},
      })
    },
    //重置
    clearSearchForm() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = this.currentUser.org[0].orgId
      this.querys[3].value = this.currentUser.org[0].orgId
      this.loadData()
    },
    // 顶部搜索
    handleSearch() {
      this.loadData()
    },
    handleSelectionChange(val) {
      if (val.length !== 0) {
        this.handleDeleteActive = false
        this.handleDeleteId = val.map((item) => {
          return item.id
        })
      } else {
        this.handleDeleteActive = true
      }
    },
    handleCurrentChange(page) {
      this.queryParam.pageBean = {...this.queryParam.pageBean, page}
      this.loadData(this.queryParam)
    },
    handleSizeChange(pageSize) {
      this.queryParam.pageBean = {...this.queryParam.pageBean, pageSize}
      this.loadData(this.queryParam)
    },
  },
  computed: {
    SearchPanel() {
      return {
        '--searchPanel': this.searchPanel + 'px',
      }
    },
  },
}
</script>

<style lang="scss" scoped>
.cloumn-btn {
  border: 1px solid #2761ff;
  padding: 3px 10px;
  border-radius: 5px;
  &:nth-child(1) {
    margin-right: 5px;
  }
  &:nth-child(2) {
    margin-right: 5px;
  }
  &:nth-child(1):hover {
    background-color: #2761ff;
    color: #fff;
  }
  &:nth-child(2):hover {
    background-color: #2761ff;
    color: #fff;
  }
  // &:nth-child(2):hover {
  //   background-color: #f56c6c;
  //   color: #fff;
  //   border-color: #f56c6c;
  // }
  /deep/ i,
  span {
    font-size: 16px;
  }
}
.common-page-shadow {
  height: calc(100% - 80px);
}
/deep/ .el-tree-node__content {
  padding: 5px 0;
}

/deep/ .el-table thead tr th {
  background-color: #eee !important;
  border-right: 1px solid #dfe2e8 !important;
}
/deep/ .el-table {
  border-collapse: collapse !important;
}
</style>
